# k8s-collector

A Helm chart for Secure State Kubernetes collector

## Additional Information

This tool can be used to attach your Kubernetes cluster to CloudHealth Secure State.

By attaching your Kubernetes clusters you can take advantage of real-time monitoring for misconfigurations and security
violations corresponding to CIS Kubernetes Benchmark standards, and build a more complete image of your organization's
security posture in the cloud.

## Installing the Chart

To install the chart with the release name `chss-collector`:

The available Chart options are listed further down. Refer to this list for required and optional parameters.

### Helm 3.8+

Helm 3.8 adopted a different distribution model for Charts. OCI image registries are the preferred method of
distributing Charts going forward.

```console
$ helm install chss-collector oci://projects.registry.vmware.com/securestate/helm-charts/k8s-collector
```

### Helm <= 3.7

Helm versions <= 3.7 support distribution from Chart Repositories.

```console
$ helm repo add vmware-securestate https://projects.registry.vmware.com/chartrepo/securestate
$ helm install chss-collector vmware-securestate/k8s-collector
```

### Minimum Chart parameters

Specify the necessary values using the `--set key=value[,key=value] argument` to `helm install`. For example,

```console
$ helm install chss-collector vmware-securestate/k8s-collector \
    --namespace <YOUR NAMESPACE> \
    --create-namespace \
    --set-file credentials.secretContents.COLLECTOR_CLIENT_SECRET=<FULL PATH TO FILE> \
    --set config.clusterCloudAccountId=<CLOUD ACCOUNT ID>
    --set config.clusterName=<CLUSTER NAME> \
    --set config.clusterRegion=<CLUSTER REGION> \
    --set config.collectorId=<COLLECTOR ID> \
    --set csp.clientId=<CSP CLIENT ID> \
    --set csp.orgId=<CSP ORGANIZATION ID>
```

Users of `zsh` might need to put quotes around key/value pairs.

## Upgrading

No upgrades are available at this time.

## Uninstall

Note: when you uninstall the Collector, configured clusters will remain untouched in the Secure State UI.

```console
$ helm uninstall <RELEASE NAME> -n <YOUR NAMESPACE>
```

## Troubleshooting the deployment

The following may be useful when troubleshooting your Chart deployments.

The collector will go into a CrashLoopBackoff if there is a problem with its configuration. This is expected
behavior as it ensure that the collector is not running in a misconfigured way, and raises any misconfigurations
directly to the collector operators.

### Collector reports that location is empty

This is likely caused by deploying the Chart on a Kubernetes cluster that you self manage. A self-managed cluster is
one whose control plane is managed by you. These differ from clusters managed by cloud providers.

The chart's default configuration assumes that your cluster is managed by a cloud provider.

If you are managing your own Kubernetes control plane, set the following value to `true`.

```console
config:
  # -- Whether the cluster is self-managed (`true``), or managed by a cloud provider (`false`).
  clusterManaged: false
```

### User is not authorized to access this resource with an explicit deny

If your collector raises this error, it is likely due to an incorrect

* `config.collectorId`
* `csp.clientId`
* `csp.orgId`
* `credentials.extraEnvVars.COLLECTOR_CLIENT_SECRET`
* An incorrect value in the collector secret you have in some other Kubernetes Secret object.

Ensure that the value in the first three bullet-points above accurately reflect your collector's configure in Secure
State.

If you specify your credential in the `extraEnvVars` field, ensure that the value that you specify is **not** base64
encoded; `helm` will automatically `base64` encode this value for you, so you should not encode it yourself.

## Requirements

Kubernetes: `>=1.18.0-0`

## Values

| Key | Type | Default | Description |
|-----|------|---------|-------------|
| collector.affinity | object | `{}` |  |
| collector.annotations | object | `{}` |  |
| collector.containerSecurityContext | object | `{}` |  |
| collector.dnsPolicy | string | `"ClusterFirst"` |  |
| collector.extraEnvVars | object | `{}` |  |
| collector.image.imagePullSecrets | list | `[]` |  |
| collector.image.pullPolicy | string | `"IfNotPresent"` |  |
| collector.image.repository | string | `"projects.registry.vmware.com/aria/k8s-collector"` |  |
| collector.image.tag | string | `"1.6.3"` |  |
| collector.initContainers | list | `[]` |  |
| collector.labels | object | `{}` |  |
| collector.nodeSelector | object | `{}` |  |
| collector.podAnnotations | object | `{}` |  |
| collector.podLabels | object | `{}` |  |
| collector.podSecurityContext | object | `{}` |  |
| collector.priorityClassName | string | `""` |  |
| collector.resources.limits.cpu | string | `"1000m"` |  |
| collector.resources.limits.memory | string | `"512Mi"` |  |
| collector.resources.requests.cpu | string | `"100m"` |  |
| collector.resources.requests.memory | string | `"64Mi"` |  |
| collector.tolerations | list | `[]` |  |
| config.clusterCloudAccountId | string | `nil` |  |
| config.clusterCloudProvider | string | `"AWS"` |  |
| config.clusterManaged | bool | `false` |  |
| config.clusterName | string | `nil` |  |
| config.clusterRegion | string | `"NA"` |  |
| config.collectorId | string | `nil` |  |
| config.enableLogging | bool | `false` |  |
| config.environment | string | `"prod"` |  |
| credentials.existingSecret | string | `nil` |  |
| credentials.extraEnvVars | object | `{}` |  |
| credentials.extraSecretRef | string | `""` |  |
| credentials.name | string | `nil` |  |
| credentials.secretContents | object | `{}` |  |
| credentials.useSecret | bool | `true` |  |
| csp.clientId | string | `nil` |  |
| csp.host | string | `"https://console.cloud.vmware.com"` |  |
| csp.orgId | string | `nil` |  |
| global.enabled | bool | `true` |  |
| global.imagePullSecrets | list | `[]` |  |
| metrics.enabled | bool | `true` |  |
| metrics.podAnnotations."prometheus.io/path" | string | `"/metrics"` |  |
| metrics.podAnnotations."prometheus.io/port" | string | `"8080"` |  |
| metrics.podAnnotations."prometheus.io/scrape" | string | `"true"` |  |
| metrics.service.annotations | object | `{}` |  |
| metrics.service.labels | object | `{}` |  |
| rbac.create | bool | `true` |  |
| serviceAccount.annotations | string | `nil` |  |
| serviceAccount.create | bool | `true` |  |
| serviceAccount.labels | string | `nil` |  |
| serviceAccount.name | string | `nil` |  |